pub(crate) enum BlockEntityInsert {
Existing(SharedBlockEntity),
Inserted(SmallVec<[SharedBlockEntity; 2]>),
}Expand description
Result of conditionally inserting a concrete entity into an empty slot.
Variants
Existing(SharedBlockEntity)
Another concrete entity already owns the position.
Inserted(SmallVec<[SharedBlockEntity; 2]>)
The new entity was inserted and may have staged callbacks.